m128

Struct m128 

pub struct m128(/* private fields */);
🔬This is a nightly-only experimental API. (stdarch_loongarch #117427)
Available on LoongArch64 only.
128-bit wide set of four f32 values, LoongArch-specific

This type is the same as the __m128 type defined in lsxintrin.h, representing a 128-bit SIMD register which internally consists of four packed f32 instances. Usage of this type typically occurs in conjunction with the lsx and higher target features for LoongArch.

Note that unlike m128i, the integer version of the 128-bit registers, this m128 type has one interpretation. Each instance of m128 corresponds to f32x4, or four f32 values packed together.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.

Most intrinsics using m128 are prefixed with lsx_ and are suffixed with “s”.