m256

Struct m256 

pub struct m256(/* private fields */);
🔬This is a nightly-only experimental API. (stdarch_loongarch #117427)
Available on LoongArch64 only.
256-bit wide set of eight f32 values, LoongArch-specific

This type is the same as the __m256 type defined in lasxintrin.h, representing a 256-bit SIMD register which internally consists of eight packed f32 instances. Usage of this type typically occurs in conjunction with the lasx target features for LoongArch.

Note that unlike m256i, the integer version of the 256-bit registers, this m256 type has one interpretation. Each instance of m256 always corresponds to f32x8, or eight f32 values packed together.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding between two consecutive elements); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.

Most intrinsics using m256 are prefixed with lasx_ and are suffixed with “s”.